summaryrefslogtreecommitdiffstats
path: root/khtml/dom/css_extensions.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /khtml/dom/css_extensions.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/dom/css_extensions.h')
-rw-r--r--khtml/dom/css_extensions.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/khtml/dom/css_extensions.h b/khtml/dom/css_extensions.h
index a6cdb2149..c236c6a14 100644
--- a/khtml/dom/css_extensions.h
+++ b/khtml/dom/css_extensions.h
@@ -61,7 +61,7 @@ public:
/**
* If \c azimuthType is \c CSS_IDENT ,
- * \c identifier contains one of left-side, far-left,
+ * \c identifier tqcontains one of left-side, far-left,
* left, center-left, center, center-right, right, far-right,
* right-side, leftwards, rightwards. The empty string if none is
* set.
@@ -184,8 +184,8 @@ public:
/**
* If \c horizontalType is \c CSS_IDENT or
- * \c CSS_INHERIT , this attribute contains the string
- * representation of the ident, otherwise it contains an empty
+ * \c CSS_INHERIT , this attribute tqcontains the string
+ * representation of the ident, otherwise it tqcontains an empty
* string.
*
*/
@@ -193,8 +193,8 @@ public:
/**
* If \c verticalType is \c CSS_IDENT or
- * \c CSS_INHERIT , this attribute contains the string
- * representation of the ident, otherwise it contains an empty
+ * \c CSS_INHERIT , this attribute tqcontains the string
+ * representation of the ident, otherwise it tqcontains an empty
* string. The value is \c "center" if only the
* horizontalIdentifier has been set. The value is
* \c "inherit" if the horizontalIdentifier is
@@ -572,8 +572,8 @@ public:
* A code defining the type of the property. It would one of
* \c CSS_UNKNOWN or \c CSS_INHERIT . If
* the type is \c CSS_UNKNOWN , then \c uris
- * contains a list of URIs and \c predefinedCursor
- * contains an ident. Setting this attribute from
+ * tqcontains a list of URIs and \c predefinedCursor
+ * tqcontains an ident. Setting this attribute from
* \c CSS_INHERIT to \c CSS_UNKNOWN will set the
* \c predefinedCursor to \c "auto" .
*
@@ -654,7 +654,7 @@ public:
void setUri( const DOM::DOMString & );
/**
- * This attribute contains a list of strings for the format CSS
+ * This attribute tqcontains a list of strings for the format CSS
* function.
*
*/
@@ -776,8 +776,8 @@ public:
/**
* If \c width is \c CSS_IDENT or
- * \c CSS_INHERIT , this attribute contains the string
- * representation of the ident, otherwise it contains an empty
+ * \c CSS_INHERIT , this attribute tqcontains the string
+ * representation of the ident, otherwise it tqcontains an empty
* string.
*
*/
@@ -2424,8 +2424,8 @@ public:
/**
* See the <a
- * href="http://www.w3.org/TR/REC-CSS2/tables.html#propdef-table-layout">
- * table-layout property definition </a> in CSS2.
+ * href="http://www.w3.org/TR/REC-CSS2/tables.html#propdef-table-tqlayout">
+ * table-tqlayout property definition </a> in CSS2.
*
*/
DOM::DOMString tableLayout() const;
@@ -2515,14 +2515,14 @@ public:
/**
* See the <a
* href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-unicode-bidi">
* unicode-bidi property definition </a> in CSS2.
*
*/
- DOM::DOMString unicodeBidi() const;
+ DOM::DOMString tqunicodeBidi() const;
/**
- * see unicodeBidi
+ * see tqunicodeBidi
*/
void setUnicodeBidi( const DOM::DOMString & );
@@ -2515,14 +2515,14 @@ public:
/**
* See the <a
- * href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-unicode-bidi">
- * unicode-bidi property definition </a> in CSS2.
+ * href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-tqunicode-bidi">
+ * tqunicode-bidi property definition </a> in CSS2.
*
*/